﻿Imports System
Imports System.IO

Namespace VBNet_Tutorials
    Partial Module Tutorials
        Private Function RunSamples() As Integer

            ' Set the path to the license
            Dim licensePath As String = "..\SolidFramework\license.xml"

            'Initialize SolidFramework and import the license
            If Not InitializeSolidFramework(licensePath) Then
                Console.WriteLine("SolidFramework initialization failed.")
                Return -1
            End If

            'Set the path to the input file
            Dim inputFile As String = "Examples\brewpub.pdf"

            Dim filename As String = Path.GetFileNameWithoutExtension(inputFile)

            'PDF conversion samples
            ConvertPdfToWord(inputFile, Path.ChangeExtension(inputFile, ".docx"))
            ConvertPdfToHtml(inputFile, Path.ChangeExtension(inputFile, ".html"))
            ConvertPdfToExcel(inputFile, Path.ChangeExtension(inputFile, ".xlsx"))
            ConvertPdfToPowerPoint(inputFile, Path.ChangeExtension(inputFile, ".pptx"))
            ConvertPdfToImages(inputFile, ChangeFileName(inputFile, filename & "-rendered-pages"))
            ExtractPdfImages(inputFile, ChangeFileName(inputFile, filename & "-extracted-images"))
            ExtractPdfText(inputFile, Path.ChangeExtension(inputFile, ".txt"))

            'Scanning and archiving samples
            ConvertPdfToPdfA(inputFile, ChangeFileName(inputFile, filename & "-pdfa.pdf"))
            MakePdfSearchable(inputFile, ChangeFileName(inputFile, filename & "-searchable.pdf"))
            OcrTransformer(inputFile, ChangeFileName(inputFile, filename & "-ocr-transform.pdf"))
            'ConvertTiffToPdf(tiffFile, tiffFile + ".pdf") '(uncomment if you have a tiff file to convert)
            ValidatePdfA(inputFile, ChangeFileName(inputFile, "PDF-A Report.xml"))

            'PDF manipulation samples
            Dim extractedPagesFolder As String = ChangeFileName(inputFile, filename & "-pages")
            ExtractPdfPages(inputFile, extractedPagesFolder)
            CombinePdfFiles(extractedPagesFolder, ChangeFileName(inputFile, filename & "-recombined.pdf"))
            EditDocumentProperties(inputFile, ChangeFileName(inputFile, filename & "-modified-properties.pdf"))
            SecurePdfFile(inputFile, ChangeFileName(inputFile, filename & "-secure.pdf"))
            SetViewerPreferences(inputFile, ChangeFileName(inputFile, filename & "-viewer-preferences.pdf"))
            Return 0
        End Function

        Private Function ChangeFileName(ByVal path As String, ByVal newFileName As String) As String
            Return System.IO.Path.Combine(System.IO.Path.GetDirectoryName(path), newFileName)
        End Function

        Function Main(ByVal args As String()) As Integer
            Try
                Return RunSamples()
            Catch ex As Exception
                Console.WriteLine("Unhandled " & ex.[GetType]().Name & ": " & ex.Message)
                Return -2
            End Try
        End Function
    End Module
End Namespace
