﻿Imports System
Imports SolidFramework.Converters
Imports SolidFramework.Converters.Plumbing

Namespace VBNet_Tutorials
    Partial Module Tutorials
        Function MakePdfSearchable(ByVal pdfPath As String, ByVal outputPath As String) As Boolean

            ' Ensure license allows OCR
            If Not SolidFramework.License.Allows(SolidFramework.Plumbing.LicensePermissions.Ocr) Then
                Console.WriteLine("License doesn't allow OCR - skipping MakePdfSearchable")
                Console.WriteLine()
                Return False
            End If

            ' Create a PdfToPdfAConverter
            Using converter As PdfToPdfAConverter = New PdfToPdfAConverter()

                ' Add the PDF file to convert
                converter.AddSourceFile(pdfPath)

                ' Set the PDF/A mode to convert to
                converter.ValidationMode = SolidFramework.Plumbing.ValidationMode.PdfA2B

                ' Add a searchable text layer (requires a Professional+OCR license)
                converter.OcrType = OcrType.CreateSearchableTextLayer
                converter.OcrEngine = TextRecoveryEngine.SolidOCR
                converter.OcrLanguage = "en"
                converter.OcrImageCompression = SolidFramework.Imaging.Plumbing.ImageCompression.PreserveOriginal

                Console.WriteLine("Converting " & pdfPath & " to " & outputPath)

                ' Convert the file
                Dim result As ConversionStatus = converter.ConvertTo(outputPath, True)

                ' Check if it was successful (PdfAError means it wasn't PDF/A but was fixed)
                If result <> ConversionStatus.Success AndAlso result <> ConversionStatus.PdfAError Then
                    Console.WriteLine("Converting " & pdfPath & " to " & outputPath & " failed with status: " & result.ToString())
                    Console.WriteLine()
                    Return False
                End If
            End Using

            Console.WriteLine("Successfully converted " & pdfPath & " to " & outputPath)
            Console.WriteLine()
            Return True
        End Function
    End Module
End Namespace
